@@ -1019,7 +1019,7 @@ class SeqModWebAppWorker(object):
                              ("Source name/strain<br/>(Depositor-provided source name)", "source_names"),
                              ("Source TaxID<br/>(Depositor-provided TaxID)", "tax_ids"),
                              ("Scores", "identity_scores"),
-                             ("Top hit ID<br/>(Depositor-provided ID)", "ref_db_ids"),
+                             ("Top hit ID [TaxID]<br/>(Depositor-provided ID)", "ref_db_ids"),
                              ("Mismatch and differences", "warn_err_msgs"))
         #
         oL = []
